<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Wyczyść wszystkie</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Zwiń</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Więcej</translation>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation>Brak nowych powiadomień</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Centrum powiadomień</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Wyczyść wszystkie</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Zwiń</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Więcej</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Odepnij</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Przypnij</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Ustawienia powiadomień</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation>Wyczyść wszystkie</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Właśnie teraz</translation>
    </message>
</context>
</TS>